@@ -23,14 +23,20 @@ template<typename T1>
 arma_warn_unused
 inline
 typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, typename T1::elem_type >::result
-det
-  (
-  const Base<typename T1::elem_type,T1>& X
-  )
+det(const Base<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  return auxlib::det(X.get_ref());
+  const quasi_unwrap<T1> U(X.get_ref());
+  
+  arma_debug_check( (U.M.is_square() == false), "det(): given matrix must be square sized" );
+  
+  if( (U.M.n_rows > 4) && (U.M.is_diagmat()) )
+    {
+    return det(diagmat(U.M));  // call the specialised version of det()
+    }
+  
+  return auxlib::det(U.M);
   }
 
 
@@ -39,10 +45,7 @@ template<typename T1>
 arma_warn_unused
 inline
 typename T1::elem_type
-det
-  (
-  const Op<T1, op_diagmat>& X
-  )
+det(const Op<T1, op_diagmat>& X)
   {
   arma_extra_debug_sigprint();
   
@@ -79,10 +82,7 @@ template<typename T1>
 arma_warn_unused
 inline
 typename T1::elem_type
-det
-  (
-  const Op<T1, op_trimat>& X
-  )
+det(const Op<T1, op_trimat>& X)
   {
   arma_extra_debug_sigprint();
   
@@ -114,29 +114,6 @@ det
 
 
 
-//! determinant of inv(A), without doing the inverse operation
-template<typename T1>
-arma_warn_unused
-inline
-typename enable_if2< is_supported_blas_type<typename T1::elem_type>::value, typename T1::elem_type >::result
-det
-  (
-  const Op<T1,op_inv>& X
-  )
-  {
-  arma_extra_debug_sigprint();
-  
-  typedef typename T1::elem_type eT;
-  
-  const eT tmp = det(X.m);
-  
-  if(tmp == eT(0))  { arma_debug_warn("det(): denominator is zero" ); }
-  
-  return eT(1) / tmp;
-  }
-
-
-
 //! NOTE: don't use this form: it will be removed
 template<typename T1>
 arma_deprecated
